@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import httpx
+from ouro.realtime.websocket import OuroWebSocket
 from supabase import Client
 
 # from ouro import Ouro
@@ -10,10 +11,11 @@ class SyncAPIResource:
     client: httpx.Client
     database: Client
     supabase: Client
+    websocket: OuroWebSocket
 
     def __init__(self, ouro) -> None:
         self.client = ouro.client
+        self.websocket = ouro.websocket
         self.database = ouro.database
         self.supabase = ouro.supabase
-
         self.ouro = ouro
